# aviary.lfrqa

An environment designed to utilize PaperQA for answering questions from the LFRQATaskDataset. Long-form RobustQA (LFRQA) is a human-annotated dataset introduced in the RAG-QA-Arena, featuring over 1400 questions from various categories, including science.

## Installation

To install the LFRQA environment, run:

```bash
pip install 'fhaviary[lfrqa]'
```

## Usage

Refer to [this tutorial](https://github.com/Future-House/paper-qa/blob/main/docs/tutorials/running_on_lfrqa.md) for instructions on how to run the environment.

## References

[1] RAG-QA Arena (https://arxiv.org/pdf/2407.13998)
